@@ -362,6 +362,10 @@ The access control code
 
 The systemd init service
 
+=item Sys::Virt::Error::FROM_BHYVE
+
+The FreeBSD BHyve driver
+
 =back
 
 =head2 ERROR CODE CONSTANTS
@@ -732,6 +736,10 @@ Not authorized to perform the operation
 
 An error from a DBus service API
 
+=item Sys::Virt::Error::ERR_STORAGE_VOL_EXIST
+
+The storage volume already exists
+
 =back
 
 =head1 AUTHORS
